Side Annotation Plots
=====================

.. currentmodule:: heatgraphy.plotter

Mesh
----

.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    ColorMesh
    Colors
    SizedMesh
    MarkerMesh

Seaborn plots
-------------

.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Bar
    Box
    Boxen
    Violin
    Point
    Count
    Strip
    Swarm

Other plots
-----------

.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Numbers
    StackBar


Text Label
----------

.. autosummary::
    :toctree: APIs/
    :template: autosummary.rst
    :nosignatures:

    Labels
    AnnoLabels
    Title
    Chunk